==> jc-1.4.0.tar.gz: javax/crypto/ExemptionMechanismSpi.h <==
// public abstract class javax.crypto.ExemptionMechanismSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ed16a6ca818003e8 javax_crypto_ExemptionMechanismSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_ExemptionMechanismSpi_H_
#define _JC_javax_crypto_ExemptionMechanismSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AlgorithmParameters$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$sub_refs	_jc_javax_crypto_ExemptionMechanismSpi$sub_refs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs	_jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$refs	_jc_javax_crypto_ExemptionMechanismSpi$refs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$nonrefs	_jc_javax_crypto_ExemptionMechanismSpi$nonrefs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$object	_jc_javax_crypto_ExemptionMechanismSpi$object;

typedef const struct _jc_javax_crypto_ExemptionMechanismSpi$vmethods	_jc_javax_crypto_ExemptionMechanismSpi$vmethods;
typedef const struct _jc_javax_crypto_ExemptionMechanismSpi$vtable	_jc_javax_crypto_ExemptionMechanismSpi$vtable;
typedef const struct _jc_javax_crypto_ExemptionMechanismSpi$vtype	_jc_javax_crypto_ExemptionMechanismSpi$vtype;

// Constructors
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *);

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_ExemptionMechanismSpi$method$engineGenExemptionBlob$08be108bd16d3717(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *);
extern jint _jc_javax_crypto_ExemptionMechanismSpi$method$engineGenExemptionBlob$71c3c326f37c8ef2(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_byte_array *, jint);
extern jint _jc_javax_crypto_ExemptionMechanismSpi$method$engineGetOutputSize$e13ccb96d0f1b0bb(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, jint);
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$engineInit$183710cc6d343804(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *);
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$engineInit$69ebd1feb23e695c(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_java_security_AlgorithmParameters$object *);
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$engineInit$af0504f670894439(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineGenExemptionBlob$08be108bd16d3717;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineGenExemptionBlob$71c3c326f37c8ef2;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineGetOutputSize$e13ccb96d0f1b0bb;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineInit$183710cc6d343804;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineInit$69ebd1feb23e695c;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineInit$af0504f670894439;

// Virtual methods structure
struct _jc_javax_crypto_ExemptionMechanismSpi$vmethods {
	_jc_byte_array	*(*engineGenExemptionBlob$08be108bd16d3717)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *);
	jint	(*engineGenExemptionBlob$71c3c326f37c8ef2)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_byte_array *, jint);
	jint	(*engineGetOutputSize$e13ccb96d0f1b0bb)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, jint);
	void	(*engineInit$183710cc6d343804)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *);
	void	(*engineInit$69ebd1feb23e695c)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_java_security_AlgorithmParameters$object *);
	void	(*engineInit$af0504f670894439)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_crypto_ExemptionMechanismSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_ExemptionMechanismSpi$vmethods	javax_crypto_ExemptionMechanismSpi;
};

// Vtype
struct _jc_javax_crypto_ExemptionMechanismSpi$vtype {
	_jc_type			type;
	_jc_javax_crypto_ExemptionMechanismSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_ExemptionMechanismSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_ExemptionMechanismSpi$refs {
    _jc_javax_crypto_ExemptionMechanismSpi$sub_refs	javax_crypto_ExemptionMechanismSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_ExemptionMechanismSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs	javax_crypto_ExemptionMechanismSpi;
};

// Object instance structure
struct _jc_javax_crypto_ExemptionMechanismSpi$object {
	_jc_javax_crypto_ExemptionMechanismSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_ExemptionMechanismSpi$vtype	*vtype;
	_jc_javax_crypto_ExemptionMechanismSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_ExemptionMechanismSpi$vtype _jc_javax_crypto_ExemptionMechanismSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_ExemptionMechanismSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_ExemptionMechanismSpi$class_object;

#endif	/* _JC_javax_crypto_ExemptionMechanismSpi_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/ExemptionMechanismSpi.h <==
// public abstract class javax.crypto.ExemptionMechanismSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ed16a6ca818003e8 javax_crypto_ExemptionMechanismSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_ExemptionMechanismSpi_H_
#define _JC_javax_crypto_ExemptionMechanismSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AlgorithmParameters$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$sub_refs	_jc_javax_crypto_ExemptionMechanismSpi$sub_refs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs	_jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$refs	_jc_javax_crypto_ExemptionMechanismSpi$refs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$nonrefs	_jc_javax_crypto_ExemptionMechanismSpi$nonrefs;
typedef struct _jc_javax_crypto_ExemptionMechanismSpi$object	_jc_javax_crypto_ExemptionMechanismSpi$object;

typedef const struct _jc_javax_crypto_ExemptionMechanismSpi$vmethods	_jc_javax_crypto_ExemptionMechanismSpi$vmethods;
typedef const struct _jc_javax_crypto_ExemptionMechanismSpi$vtable	_jc_javax_crypto_ExemptionMechanismSpi$vtable;
typedef const struct _jc_javax_crypto_ExemptionMechanismSpi$vtype	_jc_javax_crypto_ExemptionMechanismSpi$vtype;

// Constructors
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_ExemptionMechanismSpi$method$engineGenExemptionBlob$08be108bd16d3717(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_ExemptionMechanismSpi$method$engineGenExemptionBlob$71c3c326f37c8ef2(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_ExemptionMechanismSpi$method$engineGetOutputSize$e13ccb96d0f1b0bb(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$engineInit$183710cc6d343804(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$engineInit$69ebd1feb23e695c(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_java_security_AlgorithmParameters$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_ExemptionMechanismSpi$method$engineInit$af0504f670894439(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineGenExemptionBlob$08be108bd16d3717;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineGenExemptionBlob$71c3c326f37c8ef2;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineGetOutputSize$e13ccb96d0f1b0bb;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineInit$183710cc6d343804;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineInit$69ebd1feb23e695c;
extern _jc_method _jc_javax_crypto_ExemptionMechanismSpi$method_info$engineInit$af0504f670894439;

// Virtual methods structure
struct _jc_javax_crypto_ExemptionMechanismSpi$vmethods {
	_jc_byte_array	*(*engineGenExemptionBlob$08be108bd16d3717)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *) _JC_JCNI_ATTR;
	jint	(*engineGenExemptionBlob$71c3c326f37c8ef2)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*engineGetOutputSize$e13ccb96d0f1b0bb)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, jint) _JC_JCNI_ATTR;
	void	(*engineInit$183710cc6d343804)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*engineInit$69ebd1feb23e695c)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_java_security_AlgorithmParameters$object *) _JC_JCNI_ATTR;
	void	(*engineInit$af0504f670894439)(_jc_env *, struct _jc_javax_crypto_ExemptionMechanismSpi$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_ExemptionMechanismSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_ExemptionMechanismSpi$vmethods	javax_crypto_ExemptionMechanismSpi;
};

// Vtype
struct _jc_javax_crypto_ExemptionMechanismSpi$vtype {
	_jc_type			type;
	_jc_javax_crypto_ExemptionMechanismSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_ExemptionMechanismSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_ExemptionMechanismSpi$refs {
    _jc_javax_crypto_ExemptionMechanismSpi$sub_refs	javax_crypto_ExemptionMechanismSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_ExemptionMechanismSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_ExemptionMechanismSpi$sub_nonrefs	javax_crypto_ExemptionMechanismSpi;
};

// Object instance structure
struct _jc_javax_crypto_ExemptionMechanismSpi$object {
	_jc_javax_crypto_ExemptionMechanismSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_ExemptionMechanismSpi$vtype	*vtype;
	_jc_javax_crypto_ExemptionMechanismSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_ExemptionMechanismSpi$vtype _jc_javax_crypto_ExemptionMechanismSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_ExemptionMechanismSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_ExemptionMechanismSpi$class_object;

#endif	/* _JC_javax_crypto_ExemptionMechanismSpi_H_ */
